@@ -8,20 +8,16 @@ from ctypes import c_uint16
 from netprotocols import Protocol
 
 
-class UDP(Protocol):          # IETF RFC 768
+class UDP(Protocol):  # IETF RFC 768
     _fields_ = [
         ("sport", c_uint16),  # Source port
         ("dport", c_uint16),  # Destination port
-        ("len", c_uint16),    # Header length
-        ("chksum", c_uint16)  # Header checksum
+        ("len", c_uint16),  # Header length
+        ("chksum", c_uint16),  # Header checksum
     ]
     header_len = 8
 
-    def __init__(self, *,
-                 sport: int,
-                 dport: int,
-                 len: int,
-                 chksum: int):
+    def __init__(self, *, sport: int, dport: int, len: int, chksum: int):
         super().__init__()
         self.sport = sport
         self.dport = dport
@@ -29,8 +25,10 @@ class UDP(Protocol):          # IETF RFC 768
         self.chksum = chksum
 
     def __repr__(self):
-        return f"{self.__class__.__name__}(" \
-               f"sport={self.sport}, " \
-               f"dport={self.dport}, " \
-               f"len={self.len}, " \
-               f"chksum={self.chksum})"
+        return (
+            f"{self.__class__.__name__}("
+            f"sport={self.sport}, "
+            f"dport={self.dport}, "
+            f"len={self.len}, "
+            f"chksum={self.chksum})"
+        )
